[Ocfs2-commits] jlbec commits r2036 - in trunk/fs: ocfs2/cluster
usysfs
svn-commits at oss.oracle.com
svn-commits at oss.oracle.com
Tue Mar 22 15:32:31 CST 2005
Author: jlbec
Signed-off-by: manish
Date: 2005-03-22 15:32:29 -0600 (Tue, 22 Mar 2005)
New Revision: 2036
Modified:
trunk/fs/ocfs2/cluster/nodemanager.c
trunk/fs/usysfs/bobtest.c
trunk/fs/usysfs/dir.c
trunk/fs/usysfs/usysfs.h
Log:
o Change make_kset()->make_set() to match make_object().
Signed-off-by: manish
Modified: trunk/fs/ocfs2/cluster/nodemanager.c
===================================================================
--- trunk/fs/ocfs2/cluster/nodemanager.c 2005-03-22 02:04:06 UTC (rev 2035)
+++ trunk/fs/ocfs2/cluster/nodemanager.c 2005-03-22 21:32:29 UTC (rev 2036)
@@ -572,8 +572,8 @@
}
#endif
-static struct kset *nm_cluster_set_make_kset(struct kset *kset,
- const char *name)
+static struct kset *nm_cluster_set_make_set(struct kset *kset,
+ const char *name)
{
struct nm_cluster *cluster = NULL;
struct nm_node_set *ns = NULL;
@@ -632,7 +632,7 @@
.ktype = {
.sysfs_ops = NULL, /* no attributes */
},
- .make_kset = nm_cluster_set_make_kset,
+ .make_set = nm_cluster_set_make_set,
.drop_object = nm_cluster_set_drop_object,
.owner = THIS_MODULE,
};
Modified: trunk/fs/usysfs/bobtest.c
===================================================================
--- trunk/fs/usysfs/bobtest.c 2005-03-22 02:04:06 UTC (rev 2035)
+++ trunk/fs/usysfs/bobtest.c 2005-03-22 21:32:29 UTC (rev 2036)
@@ -689,7 +689,7 @@
.sysfs_ops = &tomset_sysfs_ops,
.default_attrs = tomset_attrs,
},
- .make_kset = make_tom,
+ .make_set = make_tom,
.drop_object = drop_tom,
};
Modified: trunk/fs/usysfs/dir.c
===================================================================
--- trunk/fs/usysfs/dir.c 2005-03-22 02:04:06 UTC (rev 2035)
+++ trunk/fs/usysfs/dir.c 2005-03-22 21:32:29 UTC (rev 2036)
@@ -610,7 +610,7 @@
parent_kobj = usysfs_get_kobject(dentry->d_parent);
uktype = to_uktype(parent_kobj->ktype);
- if (!uktype || (!uktype->make_kset && !uktype->make_object)) {
+ if (!uktype || (!uktype->make_set && !uktype->make_object)) {
kobject_put(parent_kobj);
return -EPERM; /* What lack-of-mkdir returns */
}
@@ -621,8 +621,8 @@
return -ENOMEM;
}
snprintf(name, dentry->d_name.len + 1, "%s", dentry->d_name.name);
- if (uktype->make_kset) {
- kset = uktype->make_kset(to_kset(parent_kobj), name);
+ if (uktype->make_set) {
+ kset = uktype->make_set(to_kset(parent_kobj), name);
kobj = kset ? &kset->kobj : NULL;
} else {
kset = NULL;
@@ -657,7 +657,7 @@
return ret;
}
/* Sets must have make_kset() or make_object() */
static int is_set(struct kobject *kobj)
{
int ret = 0;
@@ -665,7 +665,7 @@
uktype = to_uktype(kobj->ktype);
if (uktype) {
- if (uktype->make_kset)
+ if (uktype->make_set)
ret = 1;
else if (uktype->make_object)
ret = 1;
@@ -657,7 +657,7 @@
return ret;
}
-/* Sets must have make_kset() or make_object() */
+/* Sets must have make_set() or make_object() */
static int is_set(struct kobject *kobj)
{
Modified: trunk/fs/usysfs/usysfs.h
===================================================================
--- trunk/fs/usysfs/usysfs.h 2005-03-22 02:04:06 UTC (rev 2035)
+++ trunk/fs/usysfs/usysfs.h 2005-03-22 21:32:29 UTC (rev 2036)
@@ -52,11 +52,11 @@
* Usysfs objects must have a ->ktype of type ukobj_type.
* If allow_link() exists, the object can symlink(2) out to other
* objects. If the object is a kset, it may support mkdir(2). Kset
* objects must supply one of make_kset() and make_object(). If the
* object supports make_kset(), one can create kset children. If it
* supports make_object(), one can create kobject children. If it has
* default_sets on ukset->default_sets, it has automatically created
* kset children. default_sets may coexist alongsize make_kset() or
* make_object(), but if the kset wishes to have only default_sets
* children (disallowing mkdir(2)), it must provide
* usysfs_make_no_object() as the value for make_object(). If the kset
@@ -68,7 +68,7 @@
int (*allow_link)(struct kobject *src, struct kobject *target);
int (*drop_link)(struct kobject *src, struct kobject *target);
struct kobject *(*make_object)(struct kset *kset, const char *name);
- struct kset *(*make_kset)(struct kset *kset, const char *name);
+ struct kset *(*make_set)(struct kset *kset, const char *name);
int (*commit)(struct kobject *kobj);
void (*drop_object)(struct kset *kset, struct kobject *kobj);
};
@@ -52,11 +52,11 @@
* If allow_link() exists, the object can symlink(2) out to other
* objects. If the object is a kset, it may support mkdir(2). Kset
- * objects must supply one of make_kset() and make_object(). If the
- * object supports make_kset(), one can create kset children. If it
+ * objects must supply one of make_set() and make_object(). If the
+ * object supports make_set(), one can create kset children. If it
* supports make_object(), one can create kobject children. If it has
* default_sets on ukset->default_sets, it has automatically created
@@ -52,11 +52,11 @@
* supports make_object(), one can create kobject children. If it has
* default_sets on ukset->default_sets, it has automatically created
- * kset children. default_sets may coexist alongsize make_kset() or
+ * kset children. default_sets may coexist alongsize make_set() or
* make_object(), but if the kset wishes to have only default_sets
* children (disallowing mkdir(2)), it must provide
More information about the Ocfs2-commits
mailing list